
Vsources
========


.. automodule:: opendssdirect.Vsources
            :members:
            :undoc-members:
            :show-inheritance:

.. function:: opendssdirect.Vsources.AllNames

    Get the names of all Vsources

.. function:: opendssdirect.Vsources.AngleDeg

    Get the source phase angle of first phase in degrees.Set the source phase angle of first phase in degrees.

.. function:: opendssdirect.Vsources.BasekV

    Get the source voltage in kV.Set the source voltage in kV.

.. function:: opendssdirect.Vsources.Count

    The number of VSource objects currently defined in the active circuit.

.. function:: opendssdirect.Vsources.First

    Set the first VSource to be active; returns 0 if none.

.. function:: opendssdirect.Vsources.Frequency

    Get the source frequency in Hz.Set the source frequency in Hz.

.. function:: opendssdirect.Vsources.Name

    Get the name of the active VSource.Set the name of the active VSource.

.. function:: opendssdirect.Vsources.Next

    Set the next VSource to be active; returns 0 if none.

.. function:: opendssdirect.Vsources.PU

    Get the source voltage in pu.Set the source voltage in pu.

.. function:: opendssdirect.Vsources.Phases

    Get the number of phases of the active VSource.Set the number of phases of the active VSource.

